@@ -2,10 +2,11 @@ from typing import Union
 
 import numpy as np
 
-from cca_zoo.models._stochastic._base import _BaseStochastic, tv
+from cca_zoo.models._stochastic import RCCAEigenGame
+from cca_zoo.models._stochastic._base import tv
 
 
-class PLSStochasticPower(_BaseStochastic):
+class PLSStochasticPower(RCCAEigenGame):
     r"""
     A class used to fit Stochastic PLS
 
@@ -71,7 +72,7 @@ class PLSStochasticPower(_BaseStochastic):
         timeout=0,
         worker_init_fn=None,
         epochs=1,
-        learning_rate=0.01,
+        learning_rate=None,
         initialization: Union[str, callable] = "random",
     ):
         super().__init__(
@@ -94,24 +95,17 @@ class PLSStochasticPower(_BaseStochastic):
             epochs=epochs,
             learning_rate=learning_rate,
             initialization=initialization,
+            nesterov=False,
+            line_search=False,
+            ensure_descent=False,
         )
 
-    def _update(self, views):
-        converged = True
-        projections = np.stack(
-            [view @ weight for view, weight in zip(views, self.weights)]
-        )
-        for i, view in enumerate(views):
-            projections = np.ma.array(projections, mask=False, keep_mask=False)
-            projections.mask[i] = True
-            grad = (view.T @ projections.sum(axis=0).filled()) / view.shape[0]
-            w_ = self.weights[i] + self.learning_rate * grad
-            w_ = self._orth(w_)
-            # if difference between self.weights[i] and w_ is less than tol, then return True
-            if not np.allclose(self.weights[i], w_, atol=self.tol):
-                converged = False
-            self.weights[i] = w_
-        return converged
+    def grads(self, views, u=None):
+        Aw, _,_,_ = self._get_terms(views, u)
+        return -Aw
+
+    def _gradient_step(self, y, lr, grad):
+        return self._orth(y - self.learning_rate * grad)
 
     @staticmethod
     def _orth(U):
@@ -119,14 +113,8 @@ class PLSStochasticPower(_BaseStochastic):
         Su = np.sign(np.sign(np.diag(Ru)) + 0.5)
         return Qu @ np.diag(Su)
 
-    def objective(self, views, **kwargs):
-        q = [np.linalg.qr(weight)[0] for weight in self.weights]
-        views = [self.scalers[i].transform(view) for i, view in enumerate(views)]
-        transformed_views = []
-        for i, (view) in enumerate(views):
-            transformed_view = view @ q[i]
-            transformed_views.append(transformed_view)
-        return tv(transformed_views)
-
-    def _more_tags(self):
-        return {"multiview": True, "stochastic": True}
+    def objective(self, views, u=None, k=None, projections=None):
+        q = [np.linalg.qr(weight)[0] for weight in u]
+        if projections is None:
+            projections = self.projections(views, np.vstack(q))
+        return -tv(projections)
