@@ -49,7 +49,9 @@ plt.show()
 # %%
 # Deep CCA EigenGame
 # ----------------------------
-dcca_eg = DCCA_EigenGame(latent_dims=LATENT_DIMS, encoders=[encoder_1, encoder_2],lr=1e-5)
+dcca_eg = DCCA_EigenGame(
+    latent_dims=LATENT_DIMS, encoders=[encoder_1, encoder_2], lr=1e-5
+)
 trainer = pl.Trainer(
     max_epochs=EPOCHS,
     enable_checkpointing=False,
